=============
``salt-call``
=============

Synopsis
========

::

    salt-call [options]

Description
===========

The salt-call command is used to run module functions locally on a minion 
instead of executing them from the master.

Options
=======

.. program:: salt-call

.. option:: -h, --help

    Print a usage message briefly summarizing these command-line options

.. option:: -g, --grains

    Return the information generated by the Salt grains

.. option:: -m MODULE_DIRS, --module-dirs=MODULE_DIRS

    Specify an additional directories to pull modules from, multiple
    directories can be delimited by commas

.. option:: --return RETURNER

    Set salt-call to pass the return data to one or many returner interfaces.
    To use many returner interfaces specify a comma delimited list of
    returners.

.. option:: --local

    Run salt-call locally, as if there was no master running.

.. option:: -d, --doc

    Return the documentation for the specified module or for all modules if
    none are specified

.. option:: -l LOG_LEVEL, --log-level=LOG_LEVEL

    Console log level. One of ``info``, ``none``, ``garbage``,
    ``trace``, ``warning``, ``error``, ``debug``. For the logfile
    settings see the config file. Default: ``info``.

.. option:: -c CONFIG_DIR, --config-dir=CONFIG_dir

    The location of the Salt configuration directory, this directory contains
    the configuration files for Salt master and minions. The default location
    on most systems is /etc/salt.

.. option:: --out

    Pass in an alternative outputter to display the return of data. This
    outputter can be any of the available outputters:
    grains, highstate, json, key, overstatestage, pprint, raw, txt, yaml
    Some outputters are formatted only for data returned from specific
    functions, for instance the grains outputter will not work for non grains
    data.
    If an outputter is used that does not support the data passed into it, then
    Salt will fall back on the pprint outputter and display the return data
    using the python pprint library.

.. option:: --out-indent OUTPUT_INDENT, --output-indent OUTPUT_INDENT

    Print the output indented by the provided value in spaces. Negative values
    disables indentation. Only applicable in outputters that support indentation.

.. option:: --no-color

    Disable all colored output

.. option:: --version

    Show program's version number and exit

.. option:: --versions-report

    Show program's dependencies version number and exit

See also
========

:manpage:`salt(1)`
:manpage:`salt-master(1)`
:manpage:`salt-minion(1)`
